"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RouterModuleType = exports.appRouterPromptNames = exports.promptNames = void 0;
exports.getPrompts = getPrompts;
exports.prompt = prompt;
exports.getAppRouterPrompts = getAppRouterPrompts;
const prompts_1 = require("./prompts");
const types_1 = require("./types");
Object.defineProperty(exports, "promptNames", { enumerable: true, get: function () { return types_1.promptNames; } });
Object.defineProperty(exports, "appRouterPromptNames", { enumerable: true, get: function () { return types_1.appRouterPromptNames; } });
Object.defineProperty(exports, "RouterModuleType", { enumerable: true, get: function () { return types_1.RouterModuleType; } });
const i18n_1 = require("./i18n");
const inquirer_autocomplete_prompt_1 = __importDefault(require("inquirer-autocomplete-prompt"));
const logger_helper_1 = __importDefault(require("./logger-helper"));
/**
 * Retrieves Cloud Foundry deployment configuration prompts.
 *
 * This function returns a list of cf deployment questions based on the provided application root and prompt options.
 *
 * @param {CfDeployConfigPromptOptions} promptOptions - The configuration options for prompting during cf target deployment.
 * @param logger - The logger instance to use for logging.
 * @returns {Promise<CfDeployConfigQuestions[]>} A promise that resolves to an array of questions for cf target prompting.
 */
async function getPrompts(promptOptions, logger) {
    if (logger) {
        logger_helper_1.default.logger = logger;
    }
    await (0, i18n_1.initI18nCfDeployConfigInquirer)();
    return (0, prompts_1.getQuestions)(promptOptions, logger_helper_1.default.logger);
}
/**
 * Retrieves the application router configuration prompts.
 *
 * @param {CfDeployConfigPromptOptions} promptOptions - The options for configuring application router prompts.
 * @param {Logger} [logger] - An optional logger instance.
 * @returns {Promise<CfAppRouterDeployConfigQuestions[]>} A promise that resolves to an array of
 * application router deployment configuration questions.
 */
async function getAppRouterPrompts(promptOptions, logger) {
    if (logger) {
        logger_helper_1.default.logger = logger;
    }
    await (0, i18n_1.initI18nCfDeployConfigInquirer)();
    return (0, prompts_1.getAppRouterQuestions)(promptOptions, logger_helper_1.default.logger);
}
/**
 * Prompt for cf inquirer inputs.
 *
 * @param adapter - optionally provide references to a calling inquirer instance, this supports integration to Yeoman generators, for example
 * @param promptOptions - options that can control some of the prompt behavior. See {@link CfDeployConfigPromptOptions} for details
 * @param logger - logger instance to use for logging
 * @returns the prompt answers
 */
async function prompt(adapter, promptOptions, logger) {
    const cfPrompts = await getPrompts(promptOptions, logger);
    if (adapter?.promptModule && promptOptions[types_1.promptNames.destinationName]?.useAutocomplete) {
        const pm = adapter.promptModule;
        pm.registerPrompt('autocomplete', inquirer_autocomplete_prompt_1.default);
    }
    const answers = await adapter.prompt(cfPrompts);
    return answers;
}
//# sourceMappingURL=index.js.map